(function (exports) {
'use strict';

var YoSpace = function (_akamai$amp$AdPlugin) {
  babelHelpers.inherits(YoSpace, _akamai$amp$AdPlugin);

  function YoSpace(player, config) {
    babelHelpers.classCallCheck(this, YoSpace);

    var _this = babelHelpers.possibleConstructorReturn(this, (YoSpace.__proto__ || Object.getPrototypeOf(YoSpace)).call(this, player, config));

    _this.feature = "ads";
    _this.inProgress = false;

    _this.bindHandlers(["AdBreakStart", "AdBreakEnd", "AdvertStart", "AdvertEnd", "UpdateTimeline"]);

    YSSessionManager.DEFAULTS.DEBUGGING = _this.debug;
    _this.sdk = { YSSessionManager: YSSessionManager, YSPlayerEvents: YSPlayerEvents };

    _this.onclick = _this.onclick.bind(_this);

    // setup media transform
    _this.id = "yospace";
    _this.transform = _this.transform.bind(_this);
    if (_this.config.transform !== false) _this.player.mediaTransforms.push(_this);
    return _this;
  }

  babelHelpers.createClass(YoSpace, [{
    key: "transform",
    value: function transform(media) {
      var _this2 = this;

      return this.createSession(media).then(function (url) {
        _this2.logger.log("[AMP YoSpace] Session Created", url);
        media.src = url;
        return media;
      });
    }
  }, {
    key: "createSession",
    value: function createSession(media) {
      var _this3 = this;

      var props = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      return new Promise(function (resolve, reject) {
        // TODO: Do we need to implement createForNonLinear?
        var func = media.temporalType == "live" ? "createForLive" : "createForVoD";
        _this3.sessionManager = YSSessionManager[func](media.src, props, function (result) {
          if (result == "error") return reject("Could not create session");

          _this3.sessionManager.registerPlayer(_this3);

          resolve(_this3.sessionManager.masterPlaylist());
        });
      });
    }
  }, {
    key: "reportEvent",
    value: function reportEvent(event, detail) {
      if (this.sessionManager == null) return;
      this.sessionManager.reportPlayerEvent(event, detail);
    }
  }, {
    key: "AdBreakStart",
    value: function AdBreakStart() {
      // Function gets called whenever an advert break starts
      this.player.mediaElement.addEventListener("click", this.onclick);

      this.inProgress = true;

      // TODO: We need to figure out how to populate the AdVO object
      this.dispatchEvent(new akamai.amp.Event(akamai.amp.AdEvents.BREAK_START));
    }
  }, {
    key: "AdvertStart",
    value: function AdvertStart(mediaId) {
      // Function gets called at the start of each advert within a break
      // (except for filler content - eg ident etc)

      this.dispatchEvent(new akamai.amp.Event(akamai.amp.AdEvents.STARTED));
    }
  }, {
    key: "AdvertEnd",
    value: function AdvertEnd(mediaId) {
      // Function gets called at the end of each advert within a break
      // (except for filler content - eg ident etc)

      this.dispatchEvent(new akamai.amp.Event(akamai.amp.AdEvents.ENDED));
    }
  }, {
    key: "AdBreakEnd",
    value: function AdBreakEnd() {
      // Function gets called at the end of an advert break signalling a return to main content
      this.player.mediaElement.removeEventListener("click", this.onclick);

      this.inProgress = false;
      this.dispatchEvent(new akamai.amp.Event(akamai.amp.AdEvents.BREAK_END));
    }
  }, {
    key: "UpdateTimeline",
    value: function UpdateTimeline(timeline) {
      // Function gets called whenever there is updated information concerning the playback timeline
      // (for VoD and NonLinear content only)
      console.log("YoSpace -> UpdateTimeline", timeline);
    }
  }, {
    key: "ontimeupdate",
    value: function ontimeupdate(event) {
      this.reportEvent(YSPlayerEvents.POSITION, event.detail);
    }
  }, {
    key: "onfullscreenchange",
    value: function onfullscreenchange(event) {
      this.reportEvent(YSPlayerEvents.FULLSCREEN, event.detail);
    }
  }, {
    key: "onmuted",
    value: function onmuted(event) {
      this.reportEvent(YSPlayerEvents.MUTE, event.detail);
    }
  }, {
    key: "ontimedmetadata",
    value: function ontimedmetadata(event) {
      this.reportEvent(YSPlayerEvents.METADATA, event.detail);
    }
  }, {
    key: "onmediasequencestarted",
    value: function onmediasequencestarted(event) {
      this.reportEvent(YSPlayerEvents.START);
    }
  }, {
    key: "onmediasequenceended",
    value: function onmediasequenceended(event) {
      this.reportEvent(YSPlayerEvents.END);
    }
  }, {
    key: "onpause",
    value: function onpause(event) {
      this.reportEvent(YSPlayerEvents.PAUSE);
    }
  }, {
    key: "onresume",
    value: function onresume(event) {
      this.reportEvent(YSPlayerEvents.RESUME);
    }
  }, {
    key: "onseeking",
    value: function onseeking(event) {
      this.reportEvent(YSPlayerEvents.SEEK_START, this.player.currentTime);
    }
  }, {
    key: "onseeked",
    value: function onseeked(event) {
      this.reportEvent(YSPlayerEvents.SEEK_END, this.player.currentTime);
    }
  }, {
    key: "onclick",
    value: function onclick() {
      this.reportEvent(YSPlayerEvents.CLICK);
    }
  }, {
    key: "nonlinear",
    value: function nonlinear() {
      var idx = null;
      this.reportEvent(YSPlayerEvents.NONLINEAR, idx);
    }
  }]);
  return YoSpace;
}(akamai.amp.AdPlugin);

akamai.amp.AMP.registerPlugin("yospace", akamai.amp.Plugin.createFactory(YoSpace));

exports.YoSpace = YoSpace;

}((this.akamai.amp.yospace = this.akamai.amp.yospace || {})));
//# sourceMappingURL=Yospace.js.map
